from flask import Flask, request, render_template, redirect, url_for
import json
import os
from datetime import datetime

app = Flask(__name__)

# Path where the JSON data will be stored
DATA_FILE = 'form_submissions.json'

# Function to load existing data
def load_data():
    if os.path.exists(DATA_FILE):
        with open(DATA_FILE, 'r', encoding='utf-8') as file:
            try:
                return json.load(file)
            except json.JSONDecodeError:
                return []
    return []

# Function to save form data
def save_data(data):
    existing_data = load_data()
    existing_data.append(data)
    with open(DATA_FILE, 'w', encoding='utf-8') as file:
        json.dump(existing_data, file, ensure_ascii=False, indent=4)

@app.route('/', methods=['GET'])
def index():
    # Serve the main HTML form
    return render_template('index.html')

@app.route('/mail.php', methods=['POST'])
def submit_form():
    # Process the form data
    form_data = {
        'timestamp': datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
        'name': request.form.get('name', ''),
        'lastname': request.form.get('lastname', ''),
        'phone': request.form.get('phone', ''),  # Hidden input
        'phone2': request.form.get('phone2', ''),  # Visible phone input
        'country': request.form.get('country', ''),
        'lang': request.form.get('lang', ''),
        'timezone': request.form.get('timezone', ''),
        'subid': request.form.get('subid', ''),
        'utm_source': request.form.get('utm_source', ''),
        'utm_medium': request.form.get('utm_medium', ''),
        'utm_term': request.form.get('utm_term', ''),
        'utm_content': request.form.get('utm_content', ''),
        'utm_campaign': request.form.get('utm_campaign', ''),
        'querys': request.form.get('querys', ''),  # Survey responses
        'ip_address': request.remote_addr,
        'user_agent': request.user_agent.string
    }
    
    # Save the data to JSON
    save_data(form_data)
    
    # Redirect to a thank you page or another site
    return redirect('https://thank-you-page.com')

@app.route('/view-data', methods=['GET'])
def view_data():
    # Admin page to view collected data - in a real app, secure this with authentication
    data = load_data()
    return render_template('view-data.html', data=data)

if __name__ == '__main__':
    app.run(debug=True)